==> kbibtex-0.1.3.tar.bz2: kbibtex-0.1.3/src/bibtexfileexporterxslt.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXBibTeXFileExporterXSLT_H
#define BIBTEXBibTeXFileExporterXSLT_H

#include <bibtexfileexporter.h>

namespace BibTeX
{

    class BibTeXXSLTransform;
    class BibTeXFileExporterXML;

    /**
    @author Thomas Fischer
    */
    class BibTeXFileExporterXSLT : public BibTeXFileExporter
    {
    public:
        BibTeXFileExporterXSLT( BibTeXXSLTransform *transformer );
        ~BibTeXFileExporterXSLT();

        bool save( QIODevice* iodevice, BibTeXFile* bibtexfile );
        bool save( QIODevice* iodevice, BibTeXElement* element );

    private:
        BibTeXXSLTransform *m_transformer;
        BibTeXFileExporterXML *m_exporterXML;
    };

}

#endif

==> kbibtex-0.1.4.tar.bz2: kbibtex-0.1.4/src/bibtexfileexporterxslt.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXBibTeXFileExporterXSLT_H
#define BIBTEXBibTeXFileExporterXSLT_H

#include <bibtexfileexporter.h>

namespace BibTeX
{

    class BibTeXXSLTransform;
    class BibTeXFileExporterXML;

    /**
    @author Thomas Fischer
    */
    class BibTeXFileExporterXSLT : public BibTeXFileExporter
    {
    public:
        BibTeXFileExporterXSLT( BibTeXXSLTransform *transformer );
        ~BibTeXFileExporterXSLT();

        bool save( QIODevice* iodevice, BibTeXFile* bibtexfile, QStringList *errorLog = NULL );
        bool save( QIODevice* iodevice, BibTeXElement* element, QStringList *errorLog = NULL );

    private:
        BibTeXXSLTransform *m_transformer;
        BibTeXFileExporterXML *m_exporterXML;
    };

}

#endif
